/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Resource } from "@cdktf/provider-null/lib/resource";
import { ITerraformDependable, TerraformProvider, TerraformResourceLifecycle } from "cdktf";
import { Construct } from "constructs";
export interface LocalExecConfig {
    readonly dependsOn?: ITerraformDependable[];
    readonly provider?: TerraformProvider;
    readonly lifecycle?: TerraformResourceLifecycle;
    readonly triggers?: {
        [key: string]: string;
    };
    /**
     * The command to run.
     */
    readonly command: string;
    /**
     * The working directory to run the command in.
     * If copyBeforeRun is set to true it will copy the working directory to an asset directory and take that as the base to run.
     *
     * @default process.cwd()
     */
    readonly cwd?: string;
    /**
     * If set to true, the working directory will be copied to an asset directory.
     *
     * @default false
     */
    readonly copyBeforeRun?: boolean;
    /**
     * Command to run at destroy-time.
     */
    readonly onDestroy?: string;
}
export { NullProvider as Provider } from "@cdktf/provider-null/lib/provider";
export declare class LocalExec extends Resource {
    cwd: string;
    command: string;
    onDestroy?: string;
    constructor(scope: Construct, id: string, config: LocalExecConfig);
}
